]> git.cworth.org Git - scherzo/blobdiff - score.h
Fix bugs in mismatched spelling of chord name and notes
[scherzo] / score.h
diff --git a/score.h b/score.h
index c5d275de0bc4e7614f1effed1ff6ea5d5f42308a..e71b8ab2c98b6b6754ffc551a8f26e7c4ab7fe04 100644 (file)
--- a/score.h
+++ b/score.h
@@ -122,10 +122,13 @@ score_chord_t *
 score_add_chord (score_staff_t *staff,
                 const char * name);
 
/* Remove the given chord from its staff. */
 void
-score_remove_chord (score_chord_t *chord);
+score_staff_remove_chords (score_staff_t *staff);
 
+/* Remove all chords from the score. */
+void
+score_remove_chords (score_t *score);
 
 /* Remove all notes from the given staff. */
 void
@@ -122,10 +122,13 @@ score_chord_t *
                 const char * name);
 
-/* Remove the given chord from its staff. */
+/* Remove all chords from the given staff. */
 void